@@ -2,8 +2,7 @@
 // SPDX-License-Identifier: MIT OR LGPL-2.0-or-later
 // SPDX-FileCopyrightText: 2008 litl, LLC
 
-#ifndef GI_ARG_H_
-#define GI_ARG_H_
+#pragma once
 
 #include <config.h>
 
@@ -22,16 +21,16 @@
 
 // Different roles for a GIArgument; currently used only in exception and debug
 // messages.
-typedef enum {
+enum GjsArgumentType {
     GJS_ARGUMENT_ARGUMENT,
     GJS_ARGUMENT_RETURN_VALUE,
     GJS_ARGUMENT_FIELD,
     GJS_ARGUMENT_LIST_ELEMENT,
     GJS_ARGUMENT_HASH_ELEMENT,
     GJS_ARGUMENT_ARRAY_ELEMENT
-} GjsArgumentType;
+};
 
-enum class GjsArgumentFlags : uint8_t {
+enum class [[clang::flag_enum]] GjsArgumentFlags : uint8_t {
     NONE = 0,
     MAY_BE_NULL = 1 << 0,
     CALLER_ALLOCATES = 1 << 1,
@@ -45,14 +44,14 @@ enum class GjsArgumentFlags : uint8_t {
 
 // Overload operator| so that Visual Studio won't complain
 // when converting unsigned char to GjsArgumentFlags
-GjsArgumentFlags operator|(GjsArgumentFlags const& v1, GjsArgumentFlags const& v2);
+GjsArgumentFlags operator|(GjsArgumentFlags const&, GjsArgumentFlags const&);
 
-[[nodiscard]] char* gjs_argument_display_name(const char* arg_name,
-                                              GjsArgumentType arg_type);
+[[nodiscard]]
+char* gjs_argument_display_name(const char* arg_name, GjsArgumentType);
 
 GJS_JSAPI_RETURN_CONVENTION
-bool gjs_value_to_callback_out_arg(JSContext* context, JS::HandleValue value,
-                                   const GI::ArgInfo arg_info, GIArgument* arg);
+bool gjs_value_to_callback_out_arg(JSContext*, JS::HandleValue,
+                                   const GI::ArgInfo, GIArgument*);
 
 GJS_JSAPI_RETURN_CONVENTION
 bool gjs_array_to_explicit_array(JSContext*, JS::HandleValue,
@@ -61,22 +60,13 @@ bool gjs_array_to_explicit_array(JSContext*, JS::HandleValue,
                                  void** contents, size_t* length_p);
 
 size_t gjs_type_get_element_size(GITypeTag element_tag, const GI::TypeInfo);
-// FIXME: GI::TypeInfo&?
 
 GJS_JSAPI_RETURN_CONVENTION
 bool gjs_value_to_gi_argument(JSContext*, JS::HandleValue, const GI::TypeInfo,
-                              const char* arg_name, GjsArgumentType, GITransfer,
-                              GjsArgumentFlags, GIArgument*);
+                              GjsArgumentType, GITransfer, GIArgument*,
+                              GjsArgumentFlags = GjsArgumentFlags::NONE,
+                              const char* arg_name = nullptr);
 
-GJS_JSAPI_RETURN_CONVENTION
-bool inline gjs_value_to_gi_argument(JSContext* cx, JS::HandleValue value,
-                                     const GI::TypeInfo type_info,
-                                     GjsArgumentType argument_type,
-                                     GITransfer transfer, GIArgument* arg) {
-    return gjs_value_to_gi_argument(cx, value, type_info,
-                                    nullptr /* arg_name */, argument_type,
-                                    transfer, GjsArgumentFlags::NONE, arg);
-}
 GJS_JSAPI_RETURN_CONVENTION
 bool gjs_value_to_basic_gi_argument(JSContext*, JS::HandleValue, GITypeTag,
                                     GIArgument*, const char* arg_name,
@@ -171,17 +161,10 @@ bool gjs_value_from_basic_explicit_array(JSContext*, JS::MutableHandleValue,
                                          size_t length);
 GJS_JSAPI_RETURN_CONVENTION
 bool gjs_value_from_explicit_array(JSContext*, JS::MutableHandleValue,
-                                   const GI::TypeInfo, GITransfer, GIArgument*,
-                                   size_t length);
+                                   const GI::TypeInfo, GIArgument*,
+                                   size_t length,
+                                   GITransfer = GI_TRANSFER_EVERYTHING);
 
-GJS_JSAPI_RETURN_CONVENTION
-inline bool gjs_value_from_explicit_array(JSContext* context,
-                                          JS::MutableHandleValue value_p,
-                                          const GI::TypeInfo type_info,
-                                          GIArgument* arg, size_t length) {
-    return gjs_value_from_explicit_array(context, value_p, type_info,
-                                         GI_TRANSFER_EVERYTHING, arg, length);
-}
 GJS_JSAPI_RETURN_CONVENTION
 bool gjs_value_from_byte_array_gi_argument(JSContext*, JS::MutableHandleValue,
                                            GIArgument*);
@@ -196,14 +179,8 @@ bool gjs_value_from_basic_gptrarray_gi_argument(JSContext*,
                                                 GIArgument*);
 GJS_JSAPI_RETURN_CONVENTION
 bool gjs_gi_argument_release(JSContext*, GITransfer, const GI::TypeInfo,
-                             GjsArgumentFlags, GIArgument*);
-GJS_JSAPI_RETURN_CONVENTION
-inline bool gjs_gi_argument_release(JSContext* cx, GITransfer transfer,
-                                    const GI::TypeInfo type_info,
-                                    GIArgument* arg) {
-    return gjs_gi_argument_release(cx, transfer, type_info,
-                                   GjsArgumentFlags::NONE, arg);
-}
+                             GIArgument*,
+                             GjsArgumentFlags = GjsArgumentFlags::NONE);
 void gjs_gi_argument_release_basic(GITransfer, GITypeTag, GjsArgumentFlags,
                                    GIArgument*);
 void gjs_gi_argument_release_basic_glist(GITransfer, GITypeTag element_tag,
@@ -247,38 +224,25 @@ bool gjs_gi_argument_release_in_array(JSContext*, GITransfer,
                                       const GI::TypeInfo, GIArgument*);
 GJS_JSAPI_RETURN_CONVENTION
 bool gjs_gi_argument_release_in_arg(JSContext*, GITransfer, const GI::TypeInfo,
-                                    GjsArgumentFlags, GIArgument*);
-GJS_JSAPI_RETURN_CONVENTION
-inline bool gjs_gi_argument_release_in_arg(JSContext* cx, GITransfer transfer,
-                                           const GI::TypeInfo type_info,
-                                           GIArgument* arg) {
-    return gjs_gi_argument_release_in_arg(cx, transfer, type_info,
-                                          GjsArgumentFlags::ARG_IN, arg);
-}
+                                    GIArgument*);
 
 GJS_JSAPI_RETURN_CONVENTION
-bool _gjs_flags_value_is_valid(JSContext* cx, GType gtype, int64_t value);
+bool gjs_flags_value_is_valid(JSContext*, GType, int64_t value);
 
 GJS_JSAPI_RETURN_CONVENTION
-bool gjs_array_from_strv(JSContext             *context,
-                         JS::MutableHandleValue value_p,
-                         const char           **strv);
+bool gjs_array_from_strv(JSContext*, JS::MutableHandleValue, const char** strv);
 
 GJS_JSAPI_RETURN_CONVENTION
-bool gjs_array_to_strv (JSContext   *context,
-                        JS::Value    array_value,
-                        unsigned int length,
-                        void       **arr_p);
+bool gjs_array_to_strv(JSContext*, JS::Value array_value, unsigned length,
+                       void** arr_p);
 
 GJS_JSAPI_RETURN_CONVENTION
-bool gjs_array_from_g_value_array(JSContext* cx, JS::MutableHandleValue value_p,
+bool gjs_array_from_g_value_array(JSContext*, JS::MutableHandleValue,
                                   const GI::TypeInfo param_info, GITransfer,
-                                  const GValue* gvalue);
+                                  const GValue*);
 
 GJS_JSAPI_RETURN_CONVENTION
-bool gjs_object_from_g_hash(JSContext* cx, JS::MutableHandleValue,
+bool gjs_object_from_g_hash(JSContext*, JS::MutableHandleValue,
                             const GI::TypeInfo key_param_info,
-                            const GI::TypeInfo val_param_info,
-                            GITransfer transfer, GHashTable* hash);
-
-#endif  // GI_ARG_H_
+                            const GI::TypeInfo val_param_info, GITransfer,
+                            GHashTable*);
