@@ -4,13 +4,14 @@
 // SPDX-FileCopyrightText: 2021 Canonical Ltd.
 // SPDX-FileContributor: Marco Trevisan <marco.trevisan@canonical.com>
 
-#ifndef GI_CLOSURE_H_
-#define GI_CLOSURE_H_
+#pragma once
 
 #include <config.h>
 
 #include <stddef.h>
 
+#include <type_traits>
+
 #include <glib-object.h>
 
 #include <js/TypeDecls.h>
@@ -55,33 +56,33 @@ class Closure : public GClosure {
  public:
     using Ptr = Gjs::AutoPointer<Closure, Closure, unref, ref>;
 
-    [[nodiscard]] constexpr static Closure* for_gclosure(GClosure* gclosure) {
-        // We need to do this in order to ensure this is a constant expression
-        return static_cast<Closure*>(static_cast<void*>(gclosure));
+    [[nodiscard]]
+    constexpr static Closure* for_gclosure(GClosure* gclosure) {
+        return static_cast<Closure*>(gclosure);
     }
 
-    [[nodiscard]] static Closure* create(JSContext* cx, JSObject* callable,
-                                         const char* description, bool root) {
+    [[nodiscard]]
+    static Closure* create(JSContext* cx, JSObject* callable,
+                           const char* description, bool root) {
         auto* self = new Closure(cx, callable, root, description);
         self->add_finalize_notifier<Closure>();
         return self;
     }
 
-    [[nodiscard]] static Closure* create_marshaled(JSContext* cx,
-                                                   JSObject* callable,
-                                                   const char* description,
-                                                   bool root = true) {
+    [[nodiscard]]
+    static Closure* create_marshaled(JSContext* cx, JSObject* callable,
+                                     const char* description,
+                                     bool root = true) {
         auto* self = new Closure(cx, callable, root, description);
         self->add_finalize_notifier<Closure>();
         g_closure_set_marshal(self, marshal_cb);
         return self;
     }
 
-    [[nodiscard]] static Closure* create_for_signal(JSContext* cx,
-                                                    JSObject* callable,
-                                                    const char* description,
-                                                    int signal_id) {
-        auto* self = new Closure(cx, callable, false /* root */, description);
+    [[nodiscard]]
+    static Closure* create_for_signal(JSContext* cx, JSObject* callable,
+                                      const char* description, int signal_id) {
+        auto* self = new Closure(cx, callable, /* root = */ false, description);
         self->add_finalize_notifier<Closure>();
         g_closure_set_meta_marshal(self, gjs_int_to_pointer(signal_id),
                                    marshal_cb);
@@ -89,12 +90,12 @@ class Closure : public GClosure {
     }
 
     // COMPAT: constexpr in C++23
-    JSObject* callable() const { return m_callable.get(); }
-    [[nodiscard]] constexpr JSContext* context() const { return m_cx; }
+    [[nodiscard]] JSObject* callable() const { return m_callable.get(); }
+    [[nodiscard]] constexpr JSContext* cx() const { return m_cx; }
     [[nodiscard]] constexpr bool is_valid() const { return !!m_cx; }
-    GJS_JSAPI_RETURN_CONVENTION bool invoke(JS::HandleObject,
-                                            const JS::HandleValueArray&,
-                                            JS::MutableHandleValue);
+    GJS_JSAPI_RETURN_CONVENTION
+    bool invoke(JS::HandleObject, const JS::HandleValueArray&,
+                JS::MutableHandleValue);
 
     void trace(JSTracer* tracer) {
         if (m_callable)
@@ -134,5 +135,3 @@ class Closure : public GClosure {
 };
 
 }  // namespace Gjs
-
-#endif  // GI_CLOSURE_H_
