@@ -2,8 +2,7 @@
 // SPDX-License-Identifier: MIT OR LGPL-2.0-or-later
 // SPDX-FileCopyrightText: 2008 litl, LLC
 
-#ifndef GI_FUNCTION_H_
-#define GI_FUNCTION_H_
+#pragma once
 
 #include <config.h>
 
@@ -34,13 +33,13 @@ namespace JS {
 class CallArgs;
 }
 
-typedef enum {
+enum GjsParamType {
     PARAM_NORMAL,
     PARAM_SKIPPED,
     PARAM_ARRAY,
     PARAM_CALLBACK,
     PARAM_UNKNOWN,
-} GjsParamType;
+};
 
 struct GjsCallbackTrampoline : public Gjs::Closure {
     GJS_JSAPI_RETURN_CONVENTION
@@ -50,12 +49,13 @@ struct GjsCallbackTrampoline : public Gjs::Closure {
 
     ~GjsCallbackTrampoline();
 
-    void* closure() const { return m_info.closure_native_address(m_closure); }
-
-    ffi_closure* get_ffi_closure() const {
-        return m_closure;
+    [[nodiscard]]
+    void* get_func_ptr() const {
+        return m_info.closure_native_address(m_closure);
     }
 
+    [[nodiscard]] ffi_closure* get_ffi_closure() const { return m_closure; }
+
     void mark_forever();
 
     static void prepare_shutdown();
@@ -154,7 +154,8 @@ class GjsFunctionCallState {
         return first_arg_offset() + processed_c_args;
     }
 
-    [[nodiscard]] Gjs::AutoChar display_name() {
+    [[nodiscard]]
+    Gjs::AutoChar display_name() {
         mozilla::Maybe<const GI::BaseInfo> container = info.container();
         if (container) {
             return g_strdup_printf("%s.%s.%s", container->ns(),
@@ -172,5 +173,3 @@ GJS_JSAPI_RETURN_CONVENTION
 bool gjs_invoke_constructor_from_c(JSContext*, const GI::FunctionInfo,
                                    JS::HandleObject this_obj,
                                    const JS::CallArgs&, GIArgument* rvalue);
-
-#endif  // GI_FUNCTION_H_
