@@ -28,7 +28,6 @@
 #include <js/GCPolicyAPI.h>  // for IgnoreGCPolicy
 #include <mozilla/Maybe.h>
 #include <mozilla/Result.h>
-#include <mozilla/ResultVariant.h>
 #include <mozilla/Span.h>
 
 #include "gjs/auto.h"
@@ -275,11 +274,6 @@ class UnownedInfo : public InfoOperations<UnownedInfo<TAG>, TAG> {
 
     using CStruct = typename detail::InfoTraits<TAG>::CStruct;
     CStruct* m_info;
-    UnownedInfo() = delete;
-    UnownedInfo(std::nullptr_t) = delete;  // NOLINT(runtime/explicit)
-    // https://github.com/cpplint/cpplint/issues/386
-    // No need to delete move constructor; declaring a copy constructor prevents
-    // it from being generated.
 
     explicit UnownedInfo(CStruct* info) : m_info(info) { validate(); }
     [[nodiscard]] CStruct* ptr() const { return m_info; }
@@ -296,8 +290,18 @@ class UnownedInfo : public InfoOperations<UnownedInfo<TAG>, TAG> {
     }
 
  public:
+    UnownedInfo() = delete;
+    UnownedInfo(std::nullptr_t) = delete;  // NOLINT(runtime/explicit)
+    // https://github.com/cpplint/cpplint/issues/386
+    // No need to delete move constructor; declaring a copy constructor prevents
+    // it from being generated.
+
     // Copying is cheap, UnownedInfo just consists of a pointer.
     constexpr UnownedInfo(const UnownedInfo& other) : m_info(other.m_info) {}
+    // False positive when the class is a template class. In the case of self-
+    // assignment m_info and other.m_info are already the same pointer.
+    // See https://github.com/llvm/llvm-project/issues/53313
+    // NOLINTNEXTLINE(bugprone-unhandled-self-assignment)
     UnownedInfo& operator=(const UnownedInfo& other) {
         m_info = other.m_info;
         return *this;
@@ -349,9 +353,6 @@ class OwnedInfo : public InfoOperations<OwnedInfo<TAG>, TAG> {
     using CStruct = typename detail::InfoTraits<TAG>::CStruct;
     CStruct* m_info;
 
-    OwnedInfo() = delete;
-    OwnedInfo(std::nullptr_t) = delete;  // NOLINT(runtime/explicit)
-    // https://github.com/cpplint/cpplint/issues/386
     explicit OwnedInfo(CStruct* info) : m_info(info) {
         static_assert(sizeof(CStruct*) == sizeof(OwnedInfo<TAG>),
                       "OwnedInfo<T> should be byte-compatible with T*");
@@ -365,6 +366,10 @@ class OwnedInfo : public InfoOperations<OwnedInfo<TAG>, TAG> {
     [[nodiscard]] CStruct* ptr() const { return m_info; }
 
  public:
+    OwnedInfo() = delete;
+    OwnedInfo(std::nullptr_t) = delete;  // NOLINT(runtime/explicit)
+    // https://github.com/cpplint/cpplint/issues/386
+
     // Copy OwnedInfo from another OwnedInfo. Explicit because it takes a
     // reference.
     explicit OwnedInfo(const OwnedInfo& other) : OwnedInfo(other.m_info) {
@@ -375,6 +380,9 @@ class OwnedInfo : public InfoOperations<OwnedInfo<TAG>, TAG> {
         other.m_info = nullptr;
     }
     OwnedInfo& operator=(const OwnedInfo& other) {
+        if (this == &other)
+            return *this;
+
         m_info = other.m_info;
         gi_base_info_ref(m_info);
         return *this;
@@ -1426,6 +1434,11 @@ class InfoOperations<Wrapper, InfoTag::INTERFACE>
         return detail::Pointer::nullable<InfoTag::VFUNC>(
             gi_interface_info_find_vfunc(ptr(), name));
     }
+
+    operator const RegisteredTypeInfo() const {
+        return detail::Pointer::to_unowned<InfoTag::REGISTERED_TYPE>(
+            GI_REGISTERED_TYPE_INFO(ptr()));
+    }
 };
 
 template <class Wrapper>
@@ -1742,7 +1755,7 @@ class StackArgInfo : public InfoOperations<StackArgInfo, InfoTag::ARG> {
     }
 
  public:
-    constexpr StackArgInfo() {}
+    constexpr StackArgInfo() = default;
     ~StackArgInfo() { gi_base_info_clear(&m_info); }
     // Moving is okay, we copy the contents of the GIArgInfo struct and reset
     // the existing one
@@ -1770,7 +1783,7 @@ class StackTypeInfo : public InfoOperations<StackTypeInfo, InfoTag::TYPE> {
     }
 
  public:
-    constexpr StackTypeInfo() {}
+    constexpr StackTypeInfo() = default;
     ~StackTypeInfo() { gi_base_info_clear(&m_info); }
     // Moving is okay, we copy the contents of the GITypeInfo struct and reset
     // the existing one
