@@ -6,6 +6,7 @@
 
 #include <string.h>
 
+#include <string>
 #include <vector>
 
 #include <glib.h>
@@ -50,7 +51,7 @@ void platform_specific_warning_glib(JSContext* cx, const char* prefix,
     const char* base_name = resolved_name + strlen(prefix);
     Gjs::AutoChar old_name{g_strdup_printf("GLib.%s", resolved_name)};
     Gjs::AutoChar new_name{g_strdup_printf("GLib%s.%s", platform, base_name)};
-    _gjs_warn_deprecated_once_per_callsite(
+    gjs_warn_deprecated_once_per_callsite(
         cx, GjsDeprecationMessageId::PlatformSpecificTypelib,
         {old_name.get(), new_name.get()});
 }
@@ -59,18 +60,23 @@ class Ns : private Gjs::AutoChar, public CWrapper<Ns> {
     friend CWrapperPointerOps<Ns>;
     friend CWrapper<Ns>;
 
-    static constexpr auto PROTOTYPE_SLOT = GjsGlobalSlot::PROTOTYPE_ns;
+    static constexpr GjsGlobalSlot PROTOTYPE_SLOT = GjsGlobalSlot::PROTOTYPE_ns;
     static constexpr GjsDebugTopic DEBUG_TOPIC = GJS_DEBUG_GNAMESPACE;
 
     explicit Ns(const char* ns_name)
         : Gjs::AutoChar(const_cast<char*>(ns_name), Gjs::TakeOwnership{}) {
         GJS_INC_COUNTER(ns);
+
+#if !GLIB_CHECK_VERSION(2, 87, 3)
         m_is_glib = strcmp(ns_name, "GLib") == 0;
+#endif
     }
 
     ~Ns() { GJS_DEC_COUNTER(ns); }
 
+#if !GLIB_CHECK_VERSION(2, 87, 3)
     bool m_is_glib : 1;
+#endif
 
     // JSClass operations
 
@@ -110,12 +116,14 @@ class Ns : private Gjs::AutoChar, public CWrapper<Ns> {
                   "Found info type %s for '%s' in namespace '%s'",
                   info->type_string(), info->name(), info->ns());
 
+#if !GLIB_CHECK_VERSION(2, 87, 3)
         if (m_is_glib) {
             platform_specific_warning_glib(cx, "Unix", "Unix", name.get());
             platform_specific_warning_glib(cx, "unix_", "Unix", name.get());
             platform_specific_warning_glib(cx, "Win32", "Win32", name.get());
             platform_specific_warning_glib(cx, "win32_", "Win32", name.get());
         }
+#endif
 
         bool defined;
         if (!gjs_define_info(cx, obj, info.ref(), &defined)) {
@@ -183,13 +191,12 @@ class Ns : private Gjs::AutoChar, public CWrapper<Ns> {
         &Ns::finalize,
     };
 
-    // clang-format off
     static constexpr JSPropertySpec proto_props[] = {
         JS_STRING_SYM_PS(toStringTag, "GIRepositoryNamespace", JSPROP_READONLY),
         JS_PSG("__name__", &Ns::get_name, GJS_MODULE_PROP_FLAGS),
-        JS_PSG("__version__", &Ns::get_version, GJS_MODULE_PROP_FLAGS & ~JSPROP_ENUMERATE),
+        JS_PSG("__version__", &Ns::get_version,
+               GJS_MODULE_PROP_FLAGS & ~JSPROP_ENUMERATE),
         JS_PS_END};
-    // clang-format on
 
     static constexpr js::ClassSpec class_spec = {
         nullptr,  // createConstructor
@@ -228,9 +235,6 @@ class Ns : private Gjs::AutoChar, public CWrapper<Ns> {
     }
 };
 
-JSObject*
-gjs_create_ns(JSContext    *context,
-              const char   *ns_name)
-{
-    return Ns::create(context, ns_name);
+JSObject* gjs_create_ns(JSContext* cx, const char* ns_name) {
+    return Ns::create(cx, ns_name);
 }
