@@ -43,11 +43,9 @@ class JSTracer;
 namespace JS {
 class CallArgs;
 }
-namespace Gjs {
-namespace Test {
+namespace Gjs::Test {
 struct ObjectInstance;
 }
-}
 class ObjectInstance;
 class ObjectPrototype;
 class ObjectPropertyInfoCaller;
@@ -198,7 +196,7 @@ class ObjectBase
 
 // See https://bugzilla.mozilla.org/show_bug.cgi?id=1614220
 struct IdHasher {
-    typedef jsid Lookup;
+    using Lookup = jsid;
     static mozilla::HashNumber hash(jsid id) {
         if (MOZ_LIKELY(id.isString()))
             return js::DefaultHasher<JSString*>::hash(id.toString());
