@@ -2,30 +2,24 @@
 // SPDX-License-Identifier: MIT OR LGPL-2.0-or-later
 // SPDX-FileCopyrightText: 2008 litl, LLC
 
-#ifndef GI_REPO_H_
-#define GI_REPO_H_
+#pragma once
 
 #include <config.h>
 
-#include <glib-object.h>
-
 #include <js/TypeDecls.h>
-#include <mozilla/Maybe.h>
 
 #include "gi/info.h"
 #include "gjs/macros.h"
 
 GJS_JSAPI_RETURN_CONVENTION
-bool gjs_define_repo(JSContext              *cx,
-                     JS::MutableHandleObject repo);
+bool gjs_define_repo(JSContext*, JS::MutableHandleObject repo);
 GJS_JSAPI_RETURN_CONVENTION
-JSObject*   gjs_lookup_private_namespace        (JSContext      *context);
+JSObject* gjs_lookup_private_namespace(JSContext*);
 GJS_JSAPI_RETURN_CONVENTION
 JSObject* gjs_lookup_namespace_object(JSContext*, const GI::BaseInfo);
 
 GJS_JSAPI_RETURN_CONVENTION
-JSObject *gjs_lookup_namespace_object_by_name(JSContext   *context,
-                                              JS::HandleId name);
+JSObject* gjs_lookup_namespace_object_by_name(JSContext*, JS::HandleId name);
 
 GJS_JSAPI_RETURN_CONVENTION
 JSObject* gjs_lookup_generic_constructor(JSContext*, const GI::BaseInfo);
@@ -40,5 +34,3 @@ bool gjs_define_info(JSContext*, JS::HandleObject in_object, const GI::BaseInfo,
                      bool* defined);
 
 [[nodiscard]] char* gjs_hyphen_from_camel(const char* camel_name);
-
-#endif  // GI_REPO_H_
