@@ -72,6 +72,7 @@ void ToggleQueue::handle_all_toggles(Handler handler) {
 
 gboolean ToggleQueue::idle_handle_toggle(void* data) {
     auto self = Locked(static_cast<ToggleQueue*>(data));
+    g_assert(self->m_toggle_handler && "must have been enqueued with handler");
     self->handle_all_toggles(self->m_toggle_handler);
 
     return G_SOURCE_REMOVE;
@@ -142,8 +143,6 @@ void ToggleQueue::shutdown() {
 }
 
 void ToggleQueue::enqueue(ObjectInstance* obj, ToggleQueue::Direction direction,
-                          // https://trac.cppcheck.net/ticket/10733
-                          // cppcheck-suppress passedByValue
                           ToggleQueue::Handler handler) {
     g_assert(owns_lock() && "Unsafe access to queue");
 
