@@ -17,12 +17,13 @@ enum GjsDeprecationMessageId : unsigned {
     DeprecatedGObjectProperty,
     ModuleExportedLetOrConst,
     PlatformSpecificTypelib,
+    Renamed,
     LastValue,  // insert new elements before this one
 };
 
-void _gjs_warn_deprecated_once_per_callsite(JSContext*, GjsDeprecationMessageId,
-                                            unsigned max_frames = 1);
+void gjs_warn_deprecated_once_per_callsite(JSContext*, GjsDeprecationMessageId,
+                                           unsigned max_frames = 1);
 
-void _gjs_warn_deprecated_once_per_callsite(
-    JSContext*, GjsDeprecationMessageId, const std::vector<std::string>& args,
-    unsigned max_frames = 1);
+void gjs_warn_deprecated_once_per_callsite(JSContext*, GjsDeprecationMessageId,
+                                           const std::vector<std::string>& args,
+                                           unsigned max_frames = 1);
