@@ -2,8 +2,7 @@
 // SPDX-License-Identifier: MIT OR LGPL-2.0-or-later
 // SPDX-FileCopyrightText: 2013 Giovanni Campagna <scampa.giovanni@gmail.com>
 
-#ifndef GJS_ENGINE_H_
-#define GJS_ENGINE_H_
+#pragma once
 
 #include <config.h>
 
@@ -15,9 +14,7 @@ struct JSPrincipals;
 
 JSContext* gjs_create_js_context(GjsContextPrivate* uninitialized_gjs);
 
-bool gjs_load_internal_source(JSContext* cx, const char* filename, char** src,
+bool gjs_load_internal_source(JSContext*, const char* filename, char** src,
                               size_t* length);
 
 JSPrincipals* get_internal_principals();
-
-#endif  // GJS_ENGINE_H_
