@@ -1,8 +1,8 @@
 // SPDX-License-Identifier: MIT OR LGPL-2.0-or-later
 // SPDX-FileCopyrightText: 2011 Red Hat, Inc.
 
-const Regress = imports.gi.Regress;
-const GObject = imports.gi.GObject;
+import GObject from 'gi://GObject';
+import Regress from 'gi://Regress';
 
 let name = 'foo-property';
 let nick = 'Foo property';
@@ -42,10 +42,16 @@ testParamSpec('enum', [Regress.TestEnum, Regress.TestEnum.VALUE2],
 testParamSpec('flags', [Regress.TestFlags, Regress.TestFlags.FLAG2],
     Regress.TestFlags.FLAG2);
 testParamSpec('object', [GObject.Object], null);
+testParamSpec('jsobject', [], null);
 
 describe('GObject.ParamSpec object', function () {
     it("doesn't crash when resolving a non-string property", function () {
         let paramSpec = GObject.ParamSpec.string(name, nick, blurb, flags, '');
         expect(paramSpec[0]).not.toBeDefined();
     });
+
+    it('has correct object tag', function () {
+        const paramSpec = GObject.ParamSpec.string(name, nick, blurb, flags, '');
+        expect(paramSpec.toString()).toEqual('[object GObject_ParamSpec]');
+    });
 });
