@@ -2,8 +2,7 @@
 // SPDX-License-Identifier: MIT OR LGPL-2.0-or-later
 // SPDX-FileCopyrightText: 2010 litl, LLC.
 
-#ifndef MODULES_CAIRO_MODULE_H_
-#define MODULES_CAIRO_MODULE_H_
+#pragma once
 
 #include <config.h>
 
@@ -12,7 +11,4 @@
 #include "gjs/macros.h"
 
 GJS_JSAPI_RETURN_CONVENTION
-bool gjs_js_define_cairo_stuff(JSContext              *context,
-                               JS::MutableHandleObject module);
-
-#endif  // MODULES_CAIRO_MODULE_H_
+bool gjs_js_define_cairo_stuff(JSContext*, JS::MutableHandleObject module);
