@@ -2,8 +2,7 @@
 // SPDX-License-Identifier: MIT OR LGPL-2.0-or-later
 // SPDX-FileCopyrightText: 2020 Evan Welsh <contact@evanwelsh.com>
 
-#ifndef MODULES_PRINT_H_
-#define MODULES_PRINT_H_
+#pragma once
 
 #include <config.h>
 
@@ -12,6 +11,4 @@
 #include "gjs/macros.h"
 
 GJS_JSAPI_RETURN_CONVENTION
-bool gjs_define_print_stuff(JSContext* context, JS::MutableHandleObject module);
-
-#endif  // MODULES_PRINT_H_
+bool gjs_define_print_stuff(JSContext*, JS::MutableHandleObject module);
