@@ -1,11 +1,12 @@
 /* -*- mode: js; indent-tabs-mode: nil; -*- */
 /* exported Class, Interface, defineGObjectLegacyObjects,
 defineGtkLegacyObjects */
-// Copyright 2008  litl, LLC
-// Copyright 2011  Jasper St. Pierre
+// SPDX-License-Identifier: MIT
+// SPDX-FileCopyrightText: 2008 litl, LLC
+// SPDX-FileCopyrightText: 2011 Jasper St. Pierre
 
 // Class magic
-// Adapted from MooTools, MIT license
+// Adapted from MooTools
 // https://github.com/mootools/mootools-core
 
 function _Base() {
@@ -161,6 +162,7 @@ Class.prototype._construct = function (params, ...otherArgs) {
 
 /**
  * Check whether this class conforms to the interface "iface".
+ *
  * @param {object} iface a Lang.Interface
  * @returns {boolean} whether this class implements iface
  */
@@ -244,7 +246,7 @@ function _getMetaInterface(params) {
             return req.__super__;
         for (let metaclass = req.prototype.__metaclass__; metaclass;
             metaclass = metaclass.__super__) {
-            if (metaclass.hasOwnProperty('MetaInterface'))
+            if (Object.hasOwn(metaclass, 'MetaInterface'))
                 return metaclass.MetaInterface;
         }
         return null;
@@ -411,6 +413,7 @@ Interface.prototype._init = function (params) {
 
 function defineGObjectLegacyObjects(GObject) {
     const Gi = imports._gi;
+    const {_checkAccessors} = imports._common;
 
     // Some common functions between GObject.Class and GObject.Interface
 
@@ -438,7 +441,7 @@ function defineGObjectLegacyObjects(GObject) {
     }
 
     function _getGObjectInterfaces(interfaces) {
-        return interfaces.filter(iface => iface.hasOwnProperty('$gtype'));
+        return interfaces.filter(iface => Object.hasOwn(iface, '$gtype'));
     }
 
     function _propertiesAsArray(params) {
@@ -528,6 +531,8 @@ function defineGObjectLegacyObjects(GObject) {
             let propertiesArray = _propertiesAsArray(params);
             delete params.Properties;
 
+            propertiesArray.forEach(pspec => _checkAccessors(params, pspec, GObject));
+
             let newClass = Gi.register_type(parent.prototype, gtypename,
                 gflags, gobjectInterfaces, propertiesArray);
 
@@ -642,6 +647,8 @@ function defineGObjectLegacyObjects(GObject) {
 }
 
 function defineGtkLegacyObjects(GObject, Gtk) {
+    const {_createBuilderConnectFunc} = imports._common;
+
     const GtkWidgetClass = new Class({
         Name: 'GtkWidgetClass',
         Extends: GObject.Class,
@@ -678,6 +685,8 @@ function defineGtkLegacyObjects(GObject, Gtk) {
                     Gtk.Widget.set_template.call(this, template);
             }
 
+            Gtk.Widget.set_connect_func.call(this, _createBuilderConnectFunc(this));
+
             this[Gtk.template] = template;
             this[Gtk.children] = children;
             this[Gtk.internalChildren] = internalChildren;
