@@ -11,15 +11,10 @@
 #include <js/Exception.h>
 #include <js/RootingAPI.h>
 #include <js/TypeDecls.h>
+#include <js/Value.h>
 
 #include "test/gjs-test-common.h"
 
-// COMPAT: https://gitlab.gnome.org/GNOME/glib/-/merge_requests/1553
-#ifdef __clang_analyzer__
-void g_assertion_message(const char*, const char*, int, const char*,
-                         const char*) __attribute__((analyzer_noreturn));
-#endif
-
 char* gjs_test_get_exception_message(JSContext* cx) {
     if (!JS_IsExceptionPending(cx))
         return nullptr;
