@@ -8,7 +8,14 @@
 #include <errno.h>   // for errno
 #include <stdio.h>   // for sscanf, size_t
 #include <stdlib.h>  // for strtol, atoi, mkdtemp
-#include <string.h>  // for strlen, strstr, strcmp, strncmp, strcspn
+#include <string.h>  // for strlen, strstr, strncmp, strcspn
+
+#include <algorithm>  // for find, min
+#include <charconv>   // for from_chars
+#include <string>
+#include <string_view>
+#include <system_error>  // for errc
+#include <vector>
 
 #include <gio/gio.h>
 #include <glib-object.h>
@@ -19,7 +26,7 @@
 #include "gjs/coverage.h"
 #include "gjs/gerror-result.h"
 
-typedef struct _GjsCoverageFixture {
+struct GjsCoverageFixture {
     GjsContext* gjs_context;
     GjsCoverage* coverage;
 
@@ -27,7 +34,7 @@ typedef struct _GjsCoverageFixture {
     GFile* tmp_js_script;
     GFile* lcov_output_dir;
     GFile* lcov_output;
-} GjsCoverageFixture;
+};
 
 static void replace_file(GFile* file, const char* contents) {
     Gjs::AutoError error;
@@ -126,6 +133,25 @@ static const char* line_starting_with(const char* data, const char* needle) {
     return nullptr;
 }
 
+static std::string_view line_starting_with(const std::string_view& data,
+                                           const std::string& needle) {
+    const size_t needle_length = needle.size();
+    std::string_view iter = data;
+
+    while (!iter.empty()) {
+        // COMPAT: Use starts_with in C++20
+        std::string_view prefix{iter.data(),
+                                std::min(iter.size(), needle_length)};
+        if (prefix == needle)
+            return iter;
+
+        size_t newline = iter.find('\n');
+        iter.remove_prefix(std::min(iter.size(), newline + 1));
+    }
+
+    return iter;
+}
+
 static char* write_statistics_and_get_coverage_data(GjsCoverage* coverage,
                                                     GFile* lcov_output) {
     gjs_coverage_write_statistics(coverage);
@@ -134,7 +160,7 @@ static char* write_statistics_and_get_coverage_data(GjsCoverage* coverage,
 
     g_file_load_contents(lcov_output, /* cancellable = */ nullptr,
                          &coverage_data_contents, /* length out = */ nullptr,
-                         /* etag = */ nullptr, /* error = */ nullptr);
+                         /* etag_out = */ nullptr, /* error = */ nullptr);
 
     return coverage_data_contents;
 }
@@ -170,35 +196,57 @@ static void assert_coverage_data_contains_value_for_key(const char* data,
     g_assert_cmpstr(value, ==, actual);
 }
 
-using CoverageDataMatchFunc = void (*)(const char* value,
-                                       const void* user_data);
+template <typename T>
+using CoverageDataMatchFunc = void (*)(const char* value, const T& data);
 
+template <typename T>
 static void assert_coverage_data_matches_value_for_key(
-    const char* data, const char* key, CoverageDataMatchFunc match,
-    const void* user_data) {
+    const char* data, const char* key, CoverageDataMatchFunc<T> match,
+    const T& user_data) {
     const char* line = line_starting_with(data, key);
 
     g_assert_nonnull(line);
     (*match)(line, user_data);
 }
 
+template <typename T>
 static void assert_coverage_data_matches_values_for_key(
-    const char* data, const char* key, size_t n, CoverageDataMatchFunc match,
-    const void* user_data, size_t data_size) {
+    const char* data, const char* key, CoverageDataMatchFunc<T> match,
+    const std::vector<T>& user_data) {
     const char* line = line_starting_with(data, key);
     // Keep matching. If we fail to match one of them then bail out
-    const char* data_iterator = static_cast<const char*>(user_data);
+    for (auto& data_iterator : user_data) {
+        g_assert_nonnull(line);
 
-    while (line && n > 0) {
         (*match)(line, data_iterator);
 
         line = line_starting_with(line + 1, key);
-        --n;
-        data_iterator += data_size;
+    }
+}
+
+template <typename T>
+using CoverageDataExtractFunc = T (*)(std::string_view&);
+
+template <typename T>
+static void assert_coverage_data_matches_values_for_key(
+    std::string_view& data, const std::string& key,
+    CoverageDataExtractFunc<T> extract,
+    const std::vector<T>& expected_matches) {
+    std::vector<T> remaining_matches{expected_matches};
+    std::string_view line = line_starting_with(data, key);
+
+    while (!line.empty() && remaining_matches.size() > 0) {
+        T entry = (*extract)(line);
+
+        auto found = std::find(remaining_matches.begin(),
+                               remaining_matches.end(), entry);
+        g_assert_false(found == remaining_matches.end());
+        remaining_matches.erase(found);
+
+        line = line_starting_with(line, key);
     }
 
-    // If n is zero then we've found all available matches
-    g_assert_cmpuint(n, ==, 0);
+    g_assert_cmpuint(remaining_matches.size(), ==, 0);
 }
 
 static void test_covered_file_is_duplicated_into_output_if_resource(
@@ -326,21 +374,16 @@ static void test_expected_entry_not_written_for_nonexistent_file(
     g_free(coverage_data_contents);
 }
 
-typedef enum _BranchTaken {
-    NOT_EXECUTED,
-    NOT_TAKEN,
-    TAKEN
-} BranchTaken;
+enum BranchTaken { NOT_EXECUTED, NOT_TAKEN, TAKEN };
 
-typedef struct _BranchLineData {
+struct BranchLineData {
     int expected_branch_line;
     int expected_id;
     BranchTaken taken;
-} BranchLineData;
+};
 
 static void branch_at_line_should_be_taken(const char* line,
-                                           const void* user_data) {
-    auto* branch_data = static_cast<const BranchLineData*>(user_data);
+                                           const BranchLineData& branch_data) {
     int line_no, branch_id, block_no, hit_count_num;
     char hit_count[20];  // can hold maxint64 (19 digits) + nul terminator
 
@@ -362,10 +405,10 @@ static void branch_at_line_should_be_taken(const char* line,
     else
         hit_count_num = atoi(hit_count);
 
-    g_assert_cmpint(line_no, ==, branch_data->expected_branch_line);
-    g_assert_cmpint(branch_id, ==, branch_data->expected_id);
+    g_assert_cmpint(line_no, ==, branch_data.expected_branch_line);
+    g_assert_cmpint(branch_id, ==, branch_data.expected_id);
 
-    switch (branch_data->taken) {
+    switch (branch_data.taken) {
         case NOT_EXECUTED:
             g_assert_cmpint(hit_count_num, ==, -1);
             break;
@@ -397,17 +440,14 @@ static void test_single_branch_coverage_written_to_coverage_data(
         fixture->gjs_context, fixture->coverage, fixture->tmp_js_script,
         fixture->lcov_output);
 
-    const BranchLineData expected_branches[] = {{2, 0, TAKEN},
-                                                {2, 1, NOT_TAKEN}};
-    const size_t expected_branches_len = G_N_ELEMENTS(expected_branches);
+    std::vector<BranchLineData> expected_branches = {{2, 0, TAKEN},
+                                                     {2, 1, NOT_TAKEN}};
 
     /* There are two possible branches here, the second should be taken and the
      * first should not have been */
-    assert_coverage_data_matches_values_for_key(coverage_data_contents, "BRDA:",
-                                                expected_branches_len,
-                                                branch_at_line_should_be_taken,
-                                                expected_branches,
-                                                sizeof(BranchLineData));
+    assert_coverage_data_matches_values_for_key(
+        coverage_data_contents, "BRDA:", branch_at_line_should_be_taken,
+        expected_branches);
 
     assert_coverage_data_contains_value_for_key(coverage_data_contents,
                                                 "BRF:", "2");
@@ -442,19 +482,16 @@ static void test_multiple_branch_coverage_written_to_coverage_data(
         fixture->gjs_context, fixture->coverage, fixture->tmp_js_script,
         fixture->lcov_output);
 
-    const BranchLineData expected_branches[] = {
+    std::vector<BranchLineData> expected_branches{
         {2, 0, TAKEN}, {2, 1, TAKEN}, {3, 0, TAKEN},
         {3, 1, TAKEN}, {3, 2, TAKEN}, {3, 3, NOT_TAKEN},
     };
-    const size_t expected_branches_len = G_N_ELEMENTS(expected_branches);
 
     /* There are two possible branches here, the second should be taken and the
      * first should not have been */
-    assert_coverage_data_matches_values_for_key(coverage_data_contents, "BRDA:",
-                                                expected_branches_len,
-                                                branch_at_line_should_be_taken,
-                                                expected_branches,
-                                                sizeof(BranchLineData));
+    assert_coverage_data_matches_values_for_key(
+        coverage_data_contents, "BRDA:", branch_at_line_should_be_taken,
+        expected_branches);
     g_free(coverage_data_contents);
 }
 
@@ -485,19 +522,16 @@ static void test_branches_for_multiple_case_statements_fallthrough(
         fixture->gjs_context, fixture->coverage, fixture->tmp_js_script,
         fixture->lcov_output);
 
-    const BranchLineData expected_branches[] = {
+    std::vector<BranchLineData> expected_branches = {
         {2, 0, TAKEN}, {2, 1, TAKEN},     {3, 0, TAKEN},
         {3, 1, TAKEN}, {3, 2, NOT_TAKEN}, {3, 3, NOT_TAKEN},
     };
-    const size_t expected_branches_len = G_N_ELEMENTS(expected_branches);
 
     /* There are two possible branches here, the second should be taken and the
      * first should not have been */
-    assert_coverage_data_matches_values_for_key(coverage_data_contents, "BRDA:",
-                                                expected_branches_len,
-                                                branch_at_line_should_be_taken,
-                                                expected_branches,
-                                                sizeof(BranchLineData));
+    assert_coverage_data_matches_values_for_key(
+        coverage_data_contents, "BRDA:", branch_at_line_should_be_taken,
+        expected_branches);
     g_free(coverage_data_contents);
 }
 
@@ -547,19 +581,14 @@ static void test_branch_not_hit_written_to_coverage_data(void* fixture_data,
     g_free(coverage_data_contents);
 }
 
-static void has_function_name(const char* line, const void* user_data) {
-    const char* expected_function_name =
-        *(static_cast<const char* const*>(user_data));
-
+static std::string extract_function_name(std::string_view& line) {
     // Advance past "FN:"
-    line += 3;
+    line.remove_prefix(3);
 
     // Advance past the first comma
-    while (*(line - 1) != ',')
-        ++line;
+    line.remove_prefix(line.find(',') + 1);
 
-    Gjs::AutoChar actual{g_strndup(line, strlen(expected_function_name))};
-    g_assert_cmpstr(actual, ==, expected_function_name);
+    return std::string{line.substr(0, line.find('\n'))};
 }
 
 static void test_function_names_written_to_coverage_data(void* fixture_data,
@@ -577,32 +606,25 @@ static void test_function_names_written_to_coverage_data(void* fixture_data,
         fixture->gjs_context, fixture->coverage, fixture->tmp_js_script,
         fixture->lcov_output);
 
-    const char* expected_function_names[] = {
+    std::vector<std::string> expected_function_names{
         "top-level",
         "f",
         "b",
     };
-    const size_t expected_function_names_len =
-        G_N_ELEMENTS(expected_function_names);
 
-    // Just expect that we've got an FN matching out expected function names
-    assert_coverage_data_matches_values_for_key(coverage_data_contents, "FN:",
-                                                expected_function_names_len,
-                                                has_function_name,
-                                                expected_function_names,
-                                                sizeof(const char *));
+    // Just expect that we've got an FN matching our expected function names
+    std::string_view contents_view{coverage_data_contents};
+    assert_coverage_data_matches_values_for_key(
+        contents_view, "FN:", extract_function_name, expected_function_names);
+
     g_free(coverage_data_contents);
 }
 
-static void has_function_line(const char* line, const void* user_data) {
-    const char* expected_function_line =
-        *(static_cast<const char* const*>(user_data));
-
+static std::string extract_function_line(std::string_view& line) {
     // Advance past "FN:"
-    line += 3;
+    line.remove_prefix(3);
 
-    Gjs::AutoChar actual{g_strndup(line, strlen(expected_function_line))};
-    g_assert_cmpstr(actual, ==, expected_function_line);
+    return std::string{line.substr(0, line.find(','))};
 }
 
 static void test_function_lines_written_to_coverage_data(void* fixture_data,
@@ -619,55 +641,44 @@ static void test_function_lines_written_to_coverage_data(void* fixture_data,
     char* coverage_data_contents = eval_script_and_get_coverage_data(
         fixture->gjs_context, fixture->coverage, fixture->tmp_js_script,
         fixture->lcov_output);
-    const char* const expected_function_lines[] = {
+    std::vector<std::string> expected_function_lines{
         "1",
         "1",
         "3",
     };
-    const size_t expected_function_lines_len =
-        G_N_ELEMENTS(expected_function_lines);
 
-    assert_coverage_data_matches_values_for_key(coverage_data_contents, "FN:",
-                                                expected_function_lines_len,
-                                                has_function_line,
-                                                expected_function_lines,
-                                                sizeof(const char *));
+    std::string_view contents_view{coverage_data_contents};
+    assert_coverage_data_matches_values_for_key(
+        contents_view, "FN:", extract_function_line, expected_function_lines);
     g_free(coverage_data_contents);
 }
 
-typedef struct _FunctionHitCountData {
-    const char* function;
+struct FunctionHitCountData {
+    std::string function;
     unsigned hit_count_minimum;
-} FunctionHitCountData;
 
-static void hit_count_is_more_than_for_function(const char* line,
-                                                const void* user_data) {
-    auto* data = static_cast<const FunctionHitCountData*>(user_data);
+    bool operator==(const FunctionHitCountData& other) const {
+        return function == other.function &&
+               other.hit_count_minimum >= hit_count_minimum;
+    }
+};
 
+static FunctionHitCountData extract_hit_count(std::string_view& line) {
     // Advance past "FNDA:"
-    line += 5;
+    line.remove_prefix(5);
 
-    size_t max_buf_size = strcspn(line, "\n");
-    Gjs::AutoChar detected_function{g_new(char, max_buf_size + 1)};
-    Gjs::AutoChar format_string{g_strdup_printf("%%5u,%%%zus", max_buf_size)};
+    size_t comma_pos = line.find(',');
+    std::string hit_count_string{line.substr(0, comma_pos)};
+    line.remove_prefix(comma_pos + 1);
 
-    unsigned hit_count;
-    // clang-format off
-#if defined(__clang__) || __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6)
-_Pragma("GCC diagnostic push")
-_Pragma("GCC diagnostic ignored \"-Wformat-nonliteral\"")
-#endif
-    int nmatches =
-        sscanf(line, format_string, &hit_count, detected_function.get());
-#if defined(__clang__) || __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6)
-_Pragma("GCC diagnostic pop")
-#endif
-// clang-format on
-
-    g_assert_cmpint(nmatches, ==, 2);
-
-    g_assert_cmpstr(data->function, ==, detected_function);
-    g_assert_cmpuint(hit_count, >=, data->hit_count_minimum);
+    FunctionHitCountData retval;
+    auto result =
+        std::from_chars(hit_count_string.data(),
+                        hit_count_string.data() + hit_count_string.size(),
+                        retval.hit_count_minimum);
+    g_assert_true(result.ec == std::errc{});
+    retval.function = line.substr(0, line.find('\n'));
+    return retval;
 }
 
 /* For functions with whitespace between their definition and first executable
@@ -694,19 +705,17 @@ static void test_function_hit_counts_for_big_functions_written_to_coverage_data(
         fixture->gjs_context, fixture->coverage, fixture->tmp_js_script,
         fixture->lcov_output);
 
-    const FunctionHitCountData expected_hit_counts[] = {
+    std::vector<FunctionHitCountData> expected_hit_counts{
         {"top-level", 1},
         {"f", 1},
         {"b", 1},
     };
-    const size_t expected_hit_count_len = G_N_ELEMENTS(expected_hit_counts);
 
     /* There are two possible branches here, the second should be taken and the
      * first should not have been */
+    std::string_view contents_view{coverage_data_contents};
     assert_coverage_data_matches_values_for_key(
-        coverage_data_contents, "FNDA:", expected_hit_count_len,
-        hit_count_is_more_than_for_function, expected_hit_counts,
-        sizeof(FunctionHitCountData));
+        contents_view, "FNDA:", extract_hit_count, expected_hit_counts);
 
     g_free(coverage_data_contents);
 }
@@ -732,19 +741,17 @@ test_function_hit_counts_for_little_functions_written_to_coverage_data(
         fixture->gjs_context, fixture->coverage, fixture->tmp_js_script,
         fixture->lcov_output);
 
-    const FunctionHitCountData expected_hit_counts[] = {
+    std::vector<FunctionHitCountData> expected_hit_counts{
         {"top-level", 1},
         {"f", 1},
         {"b", 1},
     };
-    const size_t expected_hit_count_len = G_N_ELEMENTS(expected_hit_counts);
 
     /* There are two possible branches here, the second should be taken and the
      * first should not have been */
+    std::string_view contents_view{coverage_data_contents};
     assert_coverage_data_matches_values_for_key(
-        coverage_data_contents, "FNDA:", expected_hit_count_len,
-        hit_count_is_more_than_for_function, expected_hit_counts,
-        sizeof(FunctionHitCountData));
+        contents_view, "FNDA:", extract_hit_count, expected_hit_counts);
 
     g_free(coverage_data_contents);
 }
@@ -765,19 +772,17 @@ static void test_function_hit_counts_written_to_coverage_data(
         fixture->gjs_context, fixture->coverage, fixture->tmp_js_script,
         fixture->lcov_output);
 
-    const FunctionHitCountData expected_hit_counts[] = {
+    std::vector<FunctionHitCountData> expected_hit_counts{
         {"top-level", 1},
         {"f", 1},
         {"b", 1},
     };
-    const size_t expected_hit_count_len = G_N_ELEMENTS(expected_hit_counts);
 
     /* There are two possible branches here, the second should be taken and the
      * first should not have been */
+    std::string_view contents_view{coverage_data_contents};
     assert_coverage_data_matches_values_for_key(
-        coverage_data_contents, "FNDA:", expected_hit_count_len,
-        hit_count_is_more_than_for_function, expected_hit_counts,
-        sizeof(FunctionHitCountData));
+        contents_view, "FNDA:", extract_hit_count, expected_hit_counts);
 
     g_free(coverage_data_contents);
 }
@@ -804,15 +809,13 @@ static void test_total_function_coverage_written_to_coverage_data(
     g_free(coverage_data_contents);
 }
 
-typedef struct _LineCountIsMoreThanData {
+struct LineCountIsMoreThanData {
     unsigned expected_lineno;
     unsigned expected_to_be_more_than;
-} LineCountIsMoreThanData;
+};
 
 static void line_hit_count_is_more_than(const char* line,
-                                        const void* user_data) {
-    auto* data = static_cast<const LineCountIsMoreThanData*>(user_data);
-
+                                        const LineCountIsMoreThanData& data) {
     const char* coverage_line = &line[3];
     char* comma_ptr = nullptr;
 
@@ -826,8 +829,8 @@ static void line_hit_count_is_more_than(const char* line,
 
     g_assert_true(end_ptr[0] == '\0' || end_ptr[0] == '\n');
 
-    g_assert_cmpuint(lineno, ==, data->expected_lineno);
-    g_assert_cmpuint(value, >, data->expected_to_be_more_than);
+    g_assert_cmpuint(lineno, ==, data.expected_lineno);
+    g_assert_cmpuint(value, >, data.expected_to_be_more_than);
 }
 
 static void test_single_line_hit_written_to_coverage_data(void* fixture_data,
@@ -840,9 +843,8 @@ static void test_single_line_hit_written_to_coverage_data(void* fixture_data,
 
     const LineCountIsMoreThanData data = {1, 0};
 
-    assert_coverage_data_matches_value_for_key(coverage_data_contents, "DA:",
-                                               line_hit_count_is_more_than,
-                                               &data);
+    assert_coverage_data_matches_value_for_key(
+        coverage_data_contents, "DA:", line_hit_count_is_more_than, data);
     g_free(coverage_data_contents);
 }
 
@@ -863,11 +865,10 @@ static void test_hits_on_multiline_if_cond(void* fixture_data, const void*) {
         fixture->lcov_output);
 
     // Hits on all lines, including both lines with a condition (3 and 4)
-    const LineCountIsMoreThanData data[] = {{1, 0}, {2, 0}, {3, 0}, {4, 0}};
+    std::vector<LineCountIsMoreThanData> data{{1, 0}, {2, 0}, {3, 0}, {4, 0}};
 
-    assert_coverage_data_matches_value_for_key(coverage_data_contents, "DA:",
-                                               line_hit_count_is_more_than,
-                                               data);
+    assert_coverage_data_matches_values_for_key(
+        coverage_data_contents, "DA:", line_hit_count_is_more_than, data);
     g_free(coverage_data_contents);
 }
 
@@ -909,45 +910,38 @@ static void test_end_of_record_section_written_to_coverage_data(
     g_free(coverage_data_contents);
 }
 
-typedef struct _GjsCoverageMultipleSourcesFixture {
-    GjsCoverageFixture base_fixture;
+struct GjsCoverageMultipleSourcesFixture : GjsCoverageFixture {
     GFile* second_js_source_file;
-} GjsCoverageMultpleSourcesFixture;
+};
 
 static void gjs_coverage_multiple_source_files_to_single_output_fixture_set_up(
     void* fixture_data, const void* user_data) {
     gjs_coverage_fixture_set_up(fixture_data, user_data);
 
     auto* fixture =
-        static_cast<GjsCoverageMultpleSourcesFixture*>(fixture_data);
-    fixture->second_js_source_file =
-        g_file_get_child(fixture->base_fixture.tmp_output_dir,
-                         "gjs_coverage_second_source_file.js");
+        static_cast<GjsCoverageMultipleSourcesFixture*>(fixture_data);
+    fixture->second_js_source_file = g_file_get_child(
+        fixture->tmp_output_dir, "gjs_coverage_second_source_file.js");
 
     /* Because GjsCoverage searches the coverage paths at object-creation time,
      * we need to destroy the previously constructed one and construct it again
      */
-    Gjs::AutoChar first_js_script_path{
-        g_file_get_path(fixture->base_fixture.tmp_js_script)};
+    Gjs::AutoChar first_js_script_path{g_file_get_path(fixture->tmp_js_script)};
     Gjs::AutoChar second_js_script_path{
         g_file_get_path(fixture->second_js_source_file)};
     char* coverage_paths[] = {first_js_script_path, second_js_script_path,
                               nullptr};
 
-    g_object_unref(fixture->base_fixture.gjs_context);
-    g_object_unref(fixture->base_fixture.coverage);
-    Gjs::AutoChar output_path{
-        g_file_get_path(fixture->base_fixture.tmp_output_dir)};
+    g_object_unref(fixture->gjs_context);
+    g_object_unref(fixture->coverage);
+    Gjs::AutoChar output_path{g_file_get_path(fixture->tmp_output_dir)};
     char* search_paths[] = {output_path, nullptr};
 
-    fixture->base_fixture.gjs_context =
-        gjs_context_new_with_search_path(search_paths);
-    fixture->base_fixture.coverage =
-        gjs_coverage_new(coverage_paths, fixture->base_fixture.gjs_context,
-                         fixture->base_fixture.lcov_output_dir);
+    fixture->gjs_context = gjs_context_new_with_search_path(search_paths);
+    fixture->coverage = gjs_coverage_new(coverage_paths, fixture->gjs_context,
+                                         fixture->lcov_output_dir);
 
-    Gjs::AutoChar base_name{
-        g_file_get_basename(fixture->base_fixture.tmp_js_script)};
+    Gjs::AutoChar base_name{g_file_get_basename(fixture->tmp_js_script)};
     Gjs::AutoChar base_name_without_extension{
         g_strndup(base_name, strlen(base_name) - 3)};
     char* mock_script = g_strconcat("const FirstScript = imports.",
@@ -966,7 +960,7 @@ static void
 gjs_coverage_multiple_source_files_to_single_output_fixture_tear_down(
     void* fixture_data, const void* user_data) {
     auto* fixture =
-        static_cast<GjsCoverageMultpleSourcesFixture*>(fixture_data);
+        static_cast<GjsCoverageMultipleSourcesFixture*>(fixture_data);
     g_object_unref(fixture->second_js_source_file);
 
     gjs_coverage_fixture_tear_down(fixture_data, user_data);
@@ -975,11 +969,11 @@ gjs_coverage_multiple_source_files_to_single_output_fixture_tear_down(
 static void test_multiple_source_file_records_written_to_coverage_data(
     void* fixture_data, const void*) {
     auto* fixture =
-        static_cast<GjsCoverageMultpleSourcesFixture*>(fixture_data);
+        static_cast<GjsCoverageMultipleSourcesFixture*>(fixture_data);
 
     char* coverage_data_contents = eval_script_and_get_coverage_data(
-        fixture->base_fixture.gjs_context, fixture->base_fixture.coverage,
-        fixture->second_js_source_file, fixture->base_fixture.lcov_output);
+        fixture->gjs_context, fixture->coverage, fixture->second_js_source_file,
+        fixture->lcov_output);
 
     const char* first_sf_record =
         line_starting_with(coverage_data_contents, "SF:");
@@ -992,32 +986,30 @@ static void test_multiple_source_file_records_written_to_coverage_data(
     g_free(coverage_data_contents);
 }
 
-typedef struct _ExpectedSourceFileCoverageData {
+struct ExpectedSourceFileCoverageData {
     const char* source_file_path;
-    LineCountIsMoreThanData* more_than;
-    unsigned n_more_than_matchers;
+    std::vector<LineCountIsMoreThanData> more_than;
     const char expected_lines_hit_character;
     const char expected_lines_found_character;
-} ExpectedSourceFileCoverageData;
+};
 
 static void assert_coverage_data_for_source_file(
-    ExpectedSourceFileCoverageData* expected, const size_t expected_size,
+    const std::vector<ExpectedSourceFileCoverageData>& expected_data,
     const char* section_start) {
-    for (size_t i = 0; i < expected_size; ++i) {
-        if (strncmp(&section_start[3], expected[i].source_file_path,
-                    strlen(expected[i].source_file_path)) == 0) {
+    for (auto& expected : expected_data) {
+        if (strncmp(&section_start[3], expected.source_file_path,
+                    strlen(expected.source_file_path)) == 0) {
             assert_coverage_data_matches_values_for_key(
-                section_start, "DA:", expected[i].n_more_than_matchers,
-                line_hit_count_is_more_than, expected[i].more_than,
-                sizeof(LineCountIsMoreThanData));
+                section_start, "DA:", line_hit_count_is_more_than,
+                expected.more_than);
             const char* total_hits_record =
                 line_starting_with(section_start, "LH:");
             g_assert_cmpint(total_hits_record[3], ==,
-                            expected[i].expected_lines_hit_character);
+                            expected.expected_lines_hit_character);
             const char* total_found_record =
                 line_starting_with(section_start, "LF:");
             g_assert_cmpint(total_found_record[3], ==,
-                            expected[i].expected_lines_found_character);
+                            expected.expected_lines_found_character);
 
             return;
         }
@@ -1030,58 +1022,37 @@ static void
 test_correct_line_coverage_data_written_for_both_source_file_sections(
     void* fixture_data, const void*) {
     auto* fixture =
-        static_cast<GjsCoverageMultpleSourcesFixture*>(fixture_data);
+        static_cast<GjsCoverageMultipleSourcesFixture*>(fixture_data);
 
     char* coverage_data_contents = eval_script_and_get_coverage_data(
-        fixture->base_fixture.gjs_context, fixture->base_fixture.coverage,
-        fixture->second_js_source_file, fixture->base_fixture.lcov_output);
-
-    LineCountIsMoreThanData first_script_matcher = {1, 0};
-
-    LineCountIsMoreThanData second_script_matchers[] = {{1, 0}, {2, 0}};
+        fixture->gjs_context, fixture->coverage, fixture->second_js_source_file,
+        fixture->lcov_output);
 
     Gjs::AutoChar first_script_output_path{get_output_path_for_script_on_disk(
-        fixture->base_fixture.tmp_js_script,
-        fixture->base_fixture.lcov_output_dir)};
+        fixture->tmp_js_script, fixture->lcov_output_dir)};
     Gjs::AutoChar second_script_output_path{get_output_path_for_script_on_disk(
-        fixture->second_js_source_file, fixture->base_fixture.lcov_output_dir)};
+        fixture->second_js_source_file, fixture->lcov_output_dir)};
 
-    ExpectedSourceFileCoverageData expected[] = {
-        {
-            first_script_output_path,
-            &first_script_matcher,
-            1,
-            '1',
-            '1'
-        },
-        {
-            second_script_output_path,
-            second_script_matchers,
-            2,
-            '2',
-            '2'
-        }
-    };
-    const size_t expected_len = G_N_ELEMENTS(expected);
+    std::vector<ExpectedSourceFileCoverageData> expected{
+        {first_script_output_path, {{1, 0}}, '1', '1'},
+        {second_script_output_path, {{1, 0}, {2, 0}}, '2', '2'}};
 
     const char* first_sf_record =
         line_starting_with(coverage_data_contents, "SF:");
-    assert_coverage_data_for_source_file(expected, expected_len,
-                                         first_sf_record);
+    assert_coverage_data_for_source_file(expected, first_sf_record);
 
     const char* second_sf_record =
         line_starting_with(first_sf_record + 3, "SF:");
-    assert_coverage_data_for_source_file(expected, expected_len,
-                                         second_sf_record);
+    assert_coverage_data_for_source_file(expected, second_sf_record);
 
     g_free(coverage_data_contents);
 }
 
-typedef struct _FixturedTest {
+struct FixturedTest {
     size_t fixture_size;
     GTestFixtureFunc set_up;
     GTestFixtureFunc tear_down;
-} FixturedTest;
+};
 
 static void add_test_for_fixture(const char* name, FixturedTest* fixture,
                                  GTestFixtureFunc test_func) {
@@ -1165,7 +1136,7 @@ void gjs_test_add_tests_for_coverage() {
         &coverage_fixture, test_end_of_record_section_written_to_coverage_data);
 
     FixturedTest coverage_for_multiple_files_to_single_output_fixture = {
-        sizeof(GjsCoverageMultpleSourcesFixture),
+        sizeof(GjsCoverageMultipleSourcesFixture),
         gjs_coverage_multiple_source_files_to_single_output_fixture_set_up,
         gjs_coverage_multiple_source_files_to_single_output_fixture_tear_down};
 
