@@ -141,7 +141,7 @@ static void test_gjs_autopointer_dtor_cpp_array() {
         // using GjsAutoCppPointer1 = Gjs::AutoPointer<TestStruct[],
         // TestStruct[], Gjs::AutoPointerDeleter<TestStruct[]>>;
 
-        TestStruct* ptrs =
+        auto* ptrs =
             new TestStruct[3]{dtor_callback, dtor_callback, dtor_callback};
         Gjs::AutoCppPointer<TestStruct[]> autoptr{ptrs};
         g_assert_cmpint(autoptr[0].val, ==, 5);
@@ -200,6 +200,7 @@ static void test_gjs_autopointer_cast_free_func_type() {
     using TypedAutoPointer =
         Gjs::AutoPointer<GjsTestObject, GObject, gobject_free, gobject_copy>;
     TypedAutoPointer autoptr{gjs_test_object_new()};
+    // NOLINTNEXTLINE(bugprone-unused-local-non-trivial-variable)
     TypedAutoPointer copy{autoptr.copy()};
 }
 
@@ -310,14 +311,15 @@ static void test_gjs_autopointer_operator_move(Fixture* fx, const void*) {
     // Accessing a value after moving out of it is bad in general, but here it
     // is done on purpose, to test that the autoptr's move constructor empties
     // the old autoptr.
+    // NOLINTBEGIN(bugprone-use-after-move)
 
     test_move_fun(std::move(autoptr));
-    g_assert_nonnull(autoptr);  // cppcheck-suppress accessMoved
+    g_assert_nonnull(autoptr);
 
-    // cppcheck-suppress accessMoved
     GjsAutoTestObject autoptr2 = std::move(autoptr);
     g_assert_true(autoptr2 == fx->ptr);
-    g_assert_null(autoptr);  // cppcheck-suppress accessMoved
+    g_assert_null(autoptr);  // NOLINT(clang-analyzer-cplusplus.Move)
+    // NOLINTEND(bugprone-use-after-move)
 }
 
 static void test_gjs_autopointer_operator_swap(Fixture* fx, const void*) {
