@@ -51,19 +51,16 @@ namespace mozilla {
 union Utf8Unit;
 }
 
-namespace Gjs {
-namespace Tag {
+namespace Gjs::Tag {
 struct Enum;
 struct GBoolean;
 struct GType;
 struct UnsignedEnum;
-}  // namespace Tag
-}  // namespace Gjs
+}  // namespace Gjs::Tag
 
 #define VALID_UTF8_STRING "\303\211\303\226 foobar \343\203\237"
 
-namespace Gjs {
-namespace Test {
+namespace Gjs::Test {
 static unsigned cpp_random_seed = 0;
 
 using Gjs::Test::assert_equal;
@@ -105,9 +102,6 @@ T get_random_number() {
     } else if constexpr (std::is_pointer_v<T>) {
         return reinterpret_cast<T>(get_random_number<uintptr_t>());
     }
-
-    // COMPAT: Work around cppcheck bug https://trac.cppcheck.net/ticket/10731
-    g_assert_not_reached();
 }
 
 static void gjstest_test_func_gjs_context_construct_destroy() {
@@ -1216,23 +1210,24 @@ static void gjstest_test_func_gjs_context_eval_file_source_map() {
     g_assert_cmpuint(exit_status, ==, 1);
     g_test_assert_expected_messages();
 }
-}  // namespace Test
-}  // namespace Gjs
+}  // namespace Gjs::Test
+
+int main(int argc, char* argv[]) {
+    mozilla::Span<char*> args{argv, static_cast<size_t>(argc)};
 
-int main(int argc, char** argv) {
     using namespace Gjs::Test;  // NOLINT(build/namespaces)
 
     // Avoid interference in the tests from stray environment variable
     g_unsetenv("GJS_ENABLE_PROFILER");
     g_unsetenv("GJS_TRACE_FD");
 
-    for (int i = 0; i < argc; i++) {
+    for (size_t i = 0; i < args.size(); i++) {
         const char* seed = nullptr;
 
-        if (g_str_has_prefix(argv[i], "--cpp-seed=") && strlen(argv[i]) > 11)
-            seed = argv[i] + 11;
-        else if (i < argc - 1 && g_str_equal(argv[i], "--cpp-seed"))
-            seed = argv[i + 1];
+        if (g_str_has_prefix(args[i], "--cpp-seed=") && strlen(args[i]) > 11)
+            seed = args[i] + 11;
+        else if (i < args.size() - 1 && g_str_equal(args[i], "--cpp-seed"))
+            seed = args[i + 1];
 
         if (seed)
             cpp_random_seed = std::stoi(seed);
