@@ -1,4 +1,4 @@
-#!/bin/sh -e
+#!/bin/bash -e
 # SPDX-License-Identifier: MIT OR LGPL-2.0-or-later
 # SPDX-FileCopyrightText: 2017 Claudio André <claudioandre.br@gmail.com>
 
@@ -10,11 +10,11 @@ do_Set_Env () {
 
     #SpiderMonkey and libgjs
     export PKG_CONFIG_PATH=/usr/local/lib/pkgconfig
-    export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:/usr/local/lib64:/usr/local/lib:
-    export GI_TYPELIB_PATH=$GI_TYPELIB_PATH:/usr/lib64/girepository-1.0
+    export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:/usr/local/lib64:/usr/local/lib"
+    export GI_TYPELIB_PATH="$GI_TYPELIB_PATH:/usr/lib64/girepository-1.0"
 
     #Macros
-    export ACLOCAL_PATH=$ACLOCAL_PATH:/usr/local/share/aclocal
+    export ACLOCAL_PATH="$ACLOCAL_PATH:/usr/local/share/aclocal"
 
     export SHELL=/bin/bash
     PATH=$PATH:~/.local/bin
@@ -71,28 +71,6 @@ do_Get_Upstream_Base () {
     echo '-----------------------------------------'
 }
 
-do_Compare_With_Upstream_Base () {
-    echo '-----------------------------------------'
-    echo 'Comparing the code with upstream merge base'
-
-    sort < /cwd/base-report.txt > /cwd/base-report-sorted.txt
-    sort < /cwd/head-report.txt > /cwd/head-report-sorted.txt
-
-    NEW_WARNINGS=$(comm -13 /cwd/base-report-sorted.txt /cwd/head-report-sorted.txt | wc -l)
-    REMOVED_WARNINGS=$(comm -23 /cwd/base-report-sorted.txt /cwd/head-report-sorted.txt | wc -l)
-    if test "$NEW_WARNINGS" -ne 0; then
-        echo '-----------------------------------------'
-        echo "### $NEW_WARNINGS new warning(s) found by $1 ###"
-        echo '-----------------------------------------'
-        diff -U0 /cwd/base-report.txt /cwd/head-report.txt || true
-        echo '-----------------------------------------'
-        exit 1
-    else
-        echo "$REMOVED_WARNINGS warning(s) were fixed."
-        echo "=> $1 Ok"
-    fi
-}
-
 do_Create_Artifacts_Folder () {
     # Create the artifacts folders
     save_dir="$(pwd)"
@@ -101,7 +79,7 @@ do_Create_Artifacts_Folder () {
 
 do_Check_Script_Errors () {
     local total=0
-    total=$(cat scripts.log | grep 'not ok ' | wc -l)
+    total=$(grep -c 'not ok ' scripts.log) || true
 
     if test "$total" -gt 0; then
         echo '-----------------------------------------'
@@ -140,12 +118,14 @@ if test "$1" = "SETUP"; then
 elif test "$1" = "BUILD"; then
     do_Set_Env
 
-    DEFAULT_CONFIG_OPTS="-Dreadline=enabled -Dprofiler=enabled -Ddtrace=false \
-        -Dsystemtap=false -Dverbose_logs=false --werror -Dglib:werror=false"
-    meson setup _build $DEFAULT_CONFIG_OPTS $CONFIG_OPTS
+    DEFAULT_CONFIG_OPTS=(-Dreadline=enabled -Dprofiler=enabled -Ddtrace=false \
+        -Dsystemtap=false -Dverbose_logs=false --werror -Dglib:werror=false)
+    # shellcheck disable=SC2086 # CONFIG_OPTS comes from .gitlab-ci.yml
+    meson setup _build "${DEFAULT_CONFIG_OPTS[@]}" $CONFIG_OPTS
     ninja -C _build
 
     if test "$TEST" != "skip"; then
+        # shellcheck disable=SC2086 # TEST_OPTS comes from .gitlab-ci.yml
         xvfb-run -a meson test -C _build --suite=gjs $TEST_OPTS
     fi
 
@@ -163,36 +143,6 @@ elif test "$1" = "SH_CHECKS"; then
     installed-tests/scripts/testExamples.sh > scripts.log
     do_Check_Script_Errors
 
-elif test "$1" = "CPPLINT"; then
-    do_Print_Labels 'C/C++ Linter report '
-
-    cpplint --quiet --filter=-build/include_what_you_use \
-        $(find . -name \*.cpp -or -name \*.h | sort) 2>&1 >/dev/null | \
-        tee "$save_dir"/analysis/head-report.txt | \
-        sed -E -e 's/:[0-9]+:/:LINE:/' -e 's/  +/ /g' \
-        > /cwd/head-report.txt
-    cat "$save_dir"/analysis/head-report.txt
-    echo
-
-    do_Get_Upstream_Base
-    if test $(git rev-parse HEAD) = $(git rev-parse ci-upstream-base); then
-        echo '-----------------------------------------'
-        echo 'Running against upstream'
-        echo '=> cpplint: Nothing to do'
-        do_Done
-        exit 0
-    fi
-    git checkout ci-upstream-base
-    cpplint --quiet --filter=-build/include_what_you_use \
-        $(find . -name \*.cpp -or -name \*.h | sort) 2>&1 >/dev/null | \
-        tee "$save_dir"/analysis/base-report.txt | \
-        sed -E -e 's/:[0-9]+:/:LINE:/' -e 's/  +/ /g' \
-        > /cwd/base-report.txt
-    echo
-
-    # Compare the report with merge base and fail if new warnings are found
-    do_Compare_With_Upstream_Base "cpplint"
-
 elif test "$1" = "UPSTREAM_BASE"; then
     do_Get_Upstream_Base
     exit 0
