@@ -58,17 +58,43 @@ FWD_DECLS_IN_HEADER = (
 )
 add_fwd_header = False
 
+CPP20_VERSION = '#include <version>'
+CSTDDEF = '#include <cstddef>'
+
 FALSE_POSITIVES = (
-    # glib.h is already included, we don't need to additionally forward-declare
-    ('gjs/auto.h', 'struct _GVariant;', ''),
+    # The bodies of these structs already come before their usage,
+    # we don't need to have forward declarations of them as well
+    ('gjs/atoms.h', 'class GjsAtoms;', ''),
+    ('gjs/atoms.h', 'struct GjsSymbolAtom;', ''),
+    ('gjs/mem-private.h', 'namespace Gjs { namespace Memory { struct Counter; } }', ''),
+
+    # https://github.com/include-what-you-use/include-what-you-use/issues/1685
+    # False positive when constructing JS::GCHashMap
+    ('gi/object.h', '#include <utility>', 'for move'),
+    ('gjs/jsapi-util-error.cpp', '#include <utility>', 'for forward, move'),
+    # False positive when using JS::WeakCache::put
+    ('gi/fundamental.cpp', '#include <utility>', 'for forward'),
+    ('gi/gtype.cpp', '#include <utility>', 'for forward'),
+    # Same underlying problem, false positive due to inlined methods from
+    # gi/info.h and gi/auto.h
+    ('gi/interface.cpp', '#include <girepository/girepository.h>', 'for gi_base_info_ref'),
+    ('gjs/byteArray.cpp', '#include <girepository/girepository.h>', 'for gi_base_info_get_name, gi_bas...'),
+    ('modules/console.cpp', '#include <glib-object.h>', 'for g_object_unref'),
+
+    # For some reason IWYU wants these with angle brackets when they are
+    # already present with quotes
+    # https://github.com/include-what-you-use/include-what-you-use/issues/1087
+    ('gjs/profiler.cpp', '#include <gjs/profiler.h>', ''),
 
     # IWYU is not sure whether <utility> or <iterator> is for pair
+    # https://github.com/include-what-you-use/include-what-you-use/issues/1616
+    ('gi/object.cpp', '#include <iterator>', 'for pair'),
+    ('gi/toggle.h', '#include <iterator>', 'for pair'),
     ('test/gjs-test-utils.h', '#include <iterator>', 'for pair'),
     ('test/gjs-test-toggle-queue.cpp', '#include <iterator>', 'for pair'),
 
-    # C++20 false positive
-    # https://github.com/include-what-you-use/include-what-you-use/issues/1791
-    ('gjs/jsapi-util-root.h', '#include <version>', 'for nullptr_t'),
+    # https://github.com/include-what-you-use/include-what-you-use/issues/1808
+    ('gi/value.h', 'class ObjectBox;', ''),
 )
 
 
@@ -82,6 +108,13 @@ def output():
             else:
                 add[FWD_HEADER] = ''
 
+    # https://github.com/include-what-you-use/include-what-you-use/issues/1791
+    if add.pop(CPP20_VERSION, None) is not None and CSTDDEF not in all_includes:
+        if CSTDDEF in remove:
+            remove.pop(CSTDDEF, None)
+        else:
+            add[CSTDDEF] = 'for nullptr_t'
+
     if add or remove:
         print(f'\n== {file} ==')
         for line, why in add.items():
