@@ -2,15 +2,16 @@
 // SPDX-License-Identifier: MIT OR LGPL-2.0-or-later
 // SPDX-FileCopyrightText: 2008 litl, LLC
 
-#ifndef UTIL_LOG_H_
-#define UTIL_LOG_H_
+#pragma once
+
+#include <config.h>
 
 /* The idea of this is to be able to have one big log file for the entire
- * environment, and grep out what you care about. So each module or app
- * should have its own entry in the enum. Be sure to add new enum entries
- * to the switch in log.c
+ * environment, and grep out what you care about. So each module or app should
+ * have its own entry in the enum. Be sure to add new enum entries to the switch
+ * in log.cpp
  */
-typedef enum {
+enum GjsDebugTopic {
     GJS_DEBUG_GI_USAGE,
     GJS_DEBUG_MEMORY,
     GJS_DEBUG_CONTEXT,
@@ -18,6 +19,7 @@ typedef enum {
     GJS_DEBUG_NATIVE,
     GJS_DEBUG_CAIRO,
     GJS_DEBUG_KEEP_ALIVE,
+    GJS_DEBUG_MAINLOOP,
     GJS_DEBUG_GREPO,
     GJS_DEBUG_GNAMESPACE,
     GJS_DEBUG_GOBJECT,
@@ -31,53 +33,48 @@ typedef enum {
     GJS_DEBUG_GINTERFACE,
     GJS_DEBUG_GTYPE,
     GJS_DEBUG_LAST,
-} GjsDebugTopic;
+};
 
-/* These defines are because we have some pretty expensive and
- * extremely verbose debug output in certain areas, that's useful
- * sometimes, but just too much to compile in by default. The areas
- * tend to be broader and less focused than the ones represented by
- * GjsDebugTopic.
+/* These defines are because we have some pretty expensive and extremely verbose
+ * debug output in certain areas, that's useful sometimes, but just too much to
+ * compile in by default. The areas tend to be broader and less focused than the
+ * ones represented by GjsDebugTopic.
  *
- * Don't use these special "disabled by default" log macros to print
- * anything that's an abnormal or error situation.
+ * Don't use these special "disabled by default" log macros to print anything
+ * that's an abnormal or error situation.
  *
- * Don't use them for one-time events, either. They are for routine
- * stuff that happens over and over and would deluge the logs, so
- * should be off by default.
+ * Don't use them for one-time events, either. They are for routine stuff that
+ * happens over and over and would deluge the logs, so should be off by default.
  */
 
-/* Whether to be verbose about JavaScript property access and resolution */
+// Whether to be verbose about JavaScript property access and resolution
 #ifndef GJS_VERBOSE_ENABLE_PROPS
 #define GJS_VERBOSE_ENABLE_PROPS 0
 #endif
 
-/* Whether to be verbose about JavaScript function arg and closure marshaling */
+// Whether to be verbose about JavaScript function arg and closure marshaling
 #ifndef GJS_VERBOSE_ENABLE_MARSHAL
 #define GJS_VERBOSE_ENABLE_MARSHAL 0
 #endif
 
-/* Whether to be verbose about constructing, destroying, and gc-rooting
- * various kinds of JavaScript thingy
+/* Whether to be verbose about constructing, destroying, and gc-rooting various
+ * kinds of JavaScript thingy
  */
 #ifndef GJS_VERBOSE_ENABLE_LIFECYCLE
 #define GJS_VERBOSE_ENABLE_LIFECYCLE 0
 #endif
 
-/* Whether to log all gobject-introspection types and methods we use
- */
+// Whether to log all gobject-introspection types and methods we use
 #ifndef GJS_VERBOSE_ENABLE_GI_USAGE
 #define GJS_VERBOSE_ENABLE_GI_USAGE 0
 #endif
 
-/* Whether to log all callback GClosure debugging (finalizing, invalidating etc)
- */
+// Whether to log all callback GClosure debugging (finalizing, invalidating etc)
 #ifndef GJS_VERBOSE_ENABLE_GCLOSURE
 #define GJS_VERBOSE_ENABLE_GCLOSURE 0
 #endif
 
-/* Whether to log all GObject signal debugging
- */
+// Whether to log all GObject signal debugging
 #ifndef GJS_VERBOSE_ENABLE_GSIGNAL
 #define GJS_VERBOSE_ENABLE_GSIGNAL 0
 #endif
@@ -151,7 +148,5 @@ typedef enum {
 void gjs_log_init();
 void gjs_log_cleanup();
 
-[[gnu::format(printf, 2, 3)]] void gjs_debug(GjsDebugTopic topic,
-                                             const char* format, ...);
-
-#endif  // UTIL_LOG_H_
+[[gnu::format(printf, 2, 3)]]
+void gjs_debug(GjsDebugTopic, const char* format, ...);
